@@ -22,7 +22,7 @@ use OBO::Parser::OBOParser;
 
 my $my_parser = OBO::Parser::OBOParser->new();
 my $ontology = $my_parser->work(shift(@ARGV));
-$ontology->export(\*STDOUT, "owl");
+$ontology->export('owl', \*STDOUT);
 
 exit 0;
 
@@ -42,7 +42,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Erick Antezana
+Copyright (C) 2006-2011 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
