@@ -4,11 +4,12 @@
 # Script  : obo_union.pl
 # Purpose : Finds the union ontology from the given OBO-formatted ontologies.
 #           Creates an ontology having the union of terms and relationships from the given ontologies.
-#           Remark1  - The IDspace's are collected and added to the result ontology
-#           Remark2  - the union is made on the basis of the IDs
-#           Remark3  - the default namespace is taken from the last ontology argument
+#           Remark 1 - The IDspace's are collected and added to the result ontology
+#           Remark 2 - the union is made on the basis of the IDs
+#           Remark 3 - the default namespace is taken from the last ontology argument
+#           Remark 4 - the merging order is important while merging definitions: the one from the last ontology will be taken
 # Usage   : obo_union.pl my_first_ontology.obo my_second_ontology.obo > union.obo
-# License : Copyright (c) 2007, 2008, 2009, 2010 by Erick Antezana. All rights reserved.
+# License : Copyright (C) 2006-2011 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -32,7 +33,7 @@ foreach my $input_file (@ARGV) {
 
 my $my_ontolome = OBO::Util::Ontolome->new();
 my $union       = $my_ontolome->union(@ontologies);
-$union->export(\*STDOUT, "obo");
+$union->export('obo');
 
 exit 0;
 
@@ -45,9 +46,11 @@ obo_union.pl - Finds the union of the given OBO-formatted ontologies.
 =head1 DESCRIPTION
 
 Creates an ontology having the union of terms and relationships from the given ontologies.
-Remark1  - The IDspace's are collected and added to the result ontology
-Remark2  - the union is made on the basis of the IDs
-Remark3  - the default namespace is taken from the last ontology argument
+
+	Remark 1 - The IDspace's are collected and added to the result ontology
+	Remark 2 - the union is made on the basis of the IDs
+	Remark 3 - the default namespace is taken from the last ontology argument
+	Remark 4 - the merging order is important while merging definitions: the one from the last ontology will be taken
 
 =head1 AUTHOR
 
@@ -55,7 +58,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007, 2008, 2009, 2010 by Erick Antezana
+Copyright (C) 2006-2011 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
